elephant\.test\.test\_spike\_train\_dissimilarity module
========================================================

.. automodule:: elephant.test.test_spike_train_dissimilarity
    :members:
    :undoc-members:
    :show-inheritance:
